@@ -1,7 +1,7 @@
 /// An RGB color with 16 bits per channel.
 /// You can use [`Color::scale_to_8bit`] to convert to an 8bit RGB color.
-#[derive(Debug, Clone, Default, Eq, PartialEq)]
-#[allow(clippy::exhaustive_structs)]
+#[derive(Debug, Clone, Default, Eq, PartialEq, Hash)]
+#[non_exhaustive]
 pub struct Color {
     /// Red
     pub r: u16,
@@ -9,29 +9,38 @@ pub struct Color {
     pub g: u16,
     /// Blue
     pub b: u16,
+    // Alpha field is omitted because only rxvt-unicode supports it.
+    // If you need it, open a PR. Thanks to #[non_exhaustive] this would be a non-breaking change.
 }
 
 impl Color {
-    /// The perceived lightness of the color
-    /// as a value between `0` (black) and `100` (white)
-    /// where `50` is the perceptual "middle grey".
+    /// Creates a RGB color from its three channels: Red, Green and Blue.
+    pub fn rgb(r: u16, g: u16, b: u16) -> Self {
+        Self { r, g, b }
+    }
+
+    /// Perceptual lightness (L*) as a value between 0.0 (black) and 1.0 (white)
+    /// where 0.5 is the perceptual middle gray.
+    ///
+    /// Note that the color's alpha is ignored.
     /// ```
     /// # use terminal_colorsaurus::Color;
     /// # let color = Color::default();
-    /// let is_dark = color.perceived_lightness() <= 50;
+    /// let is_dark = color.perceived_lightness() <= 0.5;
     /// ```
-    pub fn perceived_lightness(&self) -> u8 {
-        (self.perceived_lightness_f32() * 100.) as u8
+    pub fn perceived_lightness(&self) -> f32 {
+        let color = xterm_color::Color::rgb(self.r, self.g, self.b);
+        color.perceived_lightness()
     }
 
     /// Converts the color to 8 bit precision per channel by scaling each channel.
     ///
     /// ```
     /// # use terminal_colorsaurus::Color;
-    /// let white = Color { r: u16::MAX, g: u16::MAX, b: u16::MAX };
+    /// let white = Color::rgb(u16::MAX, u16::MAX, u16::MAX);
     /// assert_eq!((u8::MAX, u8::MAX, u8::MAX), white.scale_to_8bit());
     ///
-    /// let black = Color { r: 0, g: 0, b: 0 };
+    /// let black = Color::rgb(0, 0, 0);
     /// assert_eq!((0, 0, 0), black.scale_to_8bit());
     /// ```
     pub fn scale_to_8bit(&self) -> (u8, u8, u8) {
@@ -41,11 +50,6 @@ impl Color {
             scale_to_u8(self.b),
         )
     }
-
-    pub(crate) fn perceived_lightness_f32(&self) -> f32 {
-        let color = xterm_color::Color::rgb(self.r, self.g, self.b);
-        color.perceived_lightness()
-    }
 }
 
 fn scale_to_u8(channel: u16) -> u8 {
@@ -97,7 +101,7 @@ mod tests {
     #[test]
     fn black_has_perceived_lightness_zero() {
         let black = Color::default();
-        assert_eq!(0, black.perceived_lightness())
+        assert_eq!(0.0, black.perceived_lightness())
     }
 
     #[test]
@@ -107,6 +111,6 @@ mod tests {
             g: u16::MAX,
             b: u16::MAX,
         };
-        assert_eq!(100, white.perceived_lightness())
+        assert_eq!(1.0, white.perceived_lightness())
     }
 }
